@@ -47,7 +47,10 @@ class Command(Task):
         try:
             cmd_proc = subprocess.run(
                 map(str, (command, *args)),
-                capture_output=True,
+                # when Python 3.6 is no longer supported, the following two
+                # lines can be replaced by capture_output=True,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
                 cwd=cwd,
                 check=True,
             )
@@ -70,7 +73,7 @@ class Command(Task):
                 stdout_lines = cmd_proc.stdout.decode('UTF-8').splitlines()
                 if stdout is True:
                     self.log_info(
-                        'Command "{command}" output follows below:\n'
+                        f'Command "{command}" output follows below:\n'
                         + '\n'.join(stdout_lines)
                     )
                 elif isinstance(stdout, str):
